@@ -21,10 +21,9 @@ class Window : public AIconLabel, public sigc::trackable {
  private:
   void onEvent(const struct Ipc::ipc_response&);
   void onCmd(const struct Ipc::ipc_response&);
-  std::tuple<std::size_t, int, std::string, std::string, std::string> getFocusedNode(
+  std::tuple<std::size_t, int, std::string, std::string, std::string, std::string> getFocusedNode(
       const Json::Value& nodes, std::string& output);
   void getTree();
-  std::string rewriteTitle(const std::string& title);
   void updateAppIconName();
   void updateAppIcon();
 
@@ -35,6 +34,7 @@ class Window : public AIconLabel, public sigc::trackable {
   std::string app_class_;
   std::string old_app_id_;
   std::size_t app_nb_;
+  std::string shell_;
   unsigned app_icon_size_{24};
   bool update_app_icon_{true};
   std::string app_icon_name_;
