@@ -1,18 +1,32 @@
 #include "AModule.hpp"
+
 #include <fmt/format.h>
+
 #include <util/command.hpp>
 
 namespace waybar {
 
 AModule::AModule(const Json::Value& config, const std::string& name, const std::string& id,
                  bool enable_click, bool enable_scroll)
-    : name_(std::move(name)), config_(std::move(config)) {
+    : name_(std::move(name)),
+      config_(std::move(config)),
+      distance_scrolled_y_(0.0),
+      distance_scrolled_x_(0.0) {
   // configure events' user commands
-  if (config_["on-click"].isString() || config_["on-click-middle"].isString() ||
-      config_["on-click-backward"].isString() || config_["on-click-forward"].isString() ||
-      config_["on-click-right"].isString() || enable_click) {
+  if (enable_click) {
     event_box_.add_events(Gdk::BUTTON_PRESS_MASK);
     event_box_.signal_button_press_event().connect(sigc::mem_fun(*this, &AModule::handleToggle));
+  } else {
+    std::map<std::pair<uint, GdkEventType>, std::string>::const_iterator it{eventMap_.cbegin()};
+    while (it != eventMap_.cend()) {
+      if (config_[it->second].isString()) {
+        event_box_.add_events(Gdk::BUTTON_PRESS_MASK);
+        event_box_.signal_button_press_event().connect(
+            sigc::mem_fun(*this, &AModule::handleToggle));
+        break;
+      }
+      ++it;
+    }
   }
   if (config_["on-scroll-up"].isString() || config_["on-scroll-down"].isString() || enable_scroll) {
     event_box_.add_events(Gdk::SCROLL_MASK | Gdk::SMOOTH_SCROLL_MASK);
@@ -28,7 +42,6 @@ AModule::~AModule() {
   }
 }
 
-
 auto AModule::update() -> void {
   // Run user-provided update handler if configured
   if (config_["on-update"].isString()) {
@@ -37,18 +50,17 @@ auto AModule::update() -> void {
 }
 
 bool AModule::handleToggle(GdkEventButton* const& e) {
-  std::string format;
-  if (config_["on-click"].isString() && e->button == 1) {
-    format = config_["on-click"].asString();
-  } else if (config_["on-click-middle"].isString() && e->button == 2) {
-    format = config_["on-click-middle"].asString();
-  } else if (config_["on-click-right"].isString() && e->button == 3) {
-    format = config_["on-click-right"].asString();
-  } else if (config_["on-click-backward"].isString() && e->button == 8) {
-    format = config_["on-click-backward"].asString();
-  } else if (config_["on-click-forward"].isString() && e->button == 9) {
-    format = config_["on-click-forward"].asString();
+  const std::map<std::pair<uint, GdkEventType>, std::string>::const_iterator& rec{
+      eventMap_.find(std::pair(e->button, e->type))};
+  std::string format{(rec != eventMap_.cend()) ? rec->second : std::string{""}};
+
+  if (!format.empty()) {
+    if (config_[format].isString())
+      format = config_[format].asString();
+    else
+      format.clear();
   }
+
   if (!format.empty()) {
     pid_.push_back(util::command::forkExec(format));
   }
@@ -57,11 +69,15 @@ bool AModule::handleToggle(GdkEventButton* const& e) {
 }
 
 AModule::SCROLL_DIR AModule::getScrollDir(GdkEventScroll* e) {
-  switch (e -> direction) {
-    case GDK_SCROLL_UP: return SCROLL_DIR::UP;
-    case GDK_SCROLL_DOWN: return SCROLL_DIR::DOWN;
-    case GDK_SCROLL_LEFT: return SCROLL_DIR::LEFT;
-    case GDK_SCROLL_RIGHT: return SCROLL_DIR::RIGHT;
+  switch (e->direction) {
+    case GDK_SCROLL_UP:
+      return SCROLL_DIR::UP;
+    case GDK_SCROLL_DOWN:
+      return SCROLL_DIR::DOWN;
+    case GDK_SCROLL_LEFT:
+      return SCROLL_DIR::LEFT;
+    case GDK_SCROLL_RIGHT:
+      return SCROLL_DIR::RIGHT;
     case GDK_SCROLL_SMOOTH: {
       SCROLL_DIR dir{SCROLL_DIR::NONE};
 
@@ -99,7 +115,8 @@ AModule::SCROLL_DIR AModule::getScrollDir(GdkEventScroll* e) {
       return dir;
     }
     // Silence -Wreturn-type:
-    default: return SCROLL_DIR::NONE;
+    default:
+      return SCROLL_DIR::NONE;
   }
 }
 
