@@ -1,15 +1,11 @@
 #include "modules/clock.hpp"
 
+#include <fmt/chrono.h>
 #include <spdlog/spdlog.h>
 
-#include <iomanip>
-#if FMT_VERSION < 60000
-#include <fmt/time.h>
-#else
-#include <fmt/chrono.h>
-#endif
-
 #include <ctime>
+#include <iomanip>
+#include <regex>
 #include <sstream>
 #include <type_traits>
 
@@ -66,12 +62,40 @@ waybar::modules::Clock::Clock(const std::string& id, const Json::Value& config)
     }
   }
 
+  if (is_calendar_in_tooltip_) {
+    if (config_["on-scroll"][kCalendarPlaceholder].isInt()) {
+      calendar_shift_init_ =
+          date::months{config_["on-scroll"].get(kCalendarPlaceholder, 0).asInt()};
+      event_box_.add_events(Gdk::LEAVE_NOTIFY_MASK);
+      event_box_.signal_leave_notify_event().connect([this](GdkEventCrossing*) {
+        calendar_shift_ = date::months{0};
+        return false;
+      });
+    }
+  }
+
   if (config_["locale"].isString()) {
     locale_ = std::locale(config_["locale"].asString());
   } else {
     locale_ = std::locale("");
   }
 
+  if (config_["format-calendar-weeks"].isString()) {
+    fmt_str_weeks_ =
+        std::regex_replace(config_["format-calendar-weeks"].asString(), std::regex("\\{\\}"),
+                           (first_day_of_week() == date::Monday) ? "{:%V}" : "{:%U}");
+    fmt_weeks_left_pad_ =
+        std::regex_replace(fmt_str_weeks_, std::regex("</?[^>]+>|\\{.*\\}"), "").length();
+  } else {
+    fmt_str_weeks_ = "";
+  }
+
+  if (config_["format-calendar"].isString()) {
+    fmt_str_calendar_ = config_["format-calendar"].asString();
+  } else {
+    fmt_str_calendar_ = "{}";
+  }
+
   thread_ = [this] {
     dp.emit();
     auto now = std::chrono::system_clock::now();
@@ -96,6 +120,12 @@ auto waybar::modules::Clock::update() -> void {
   auto now = std::chrono::system_clock::now();
   waybar_time wtime = {locale_,
                        date::make_zoned(time_zone, date::floor<std::chrono::seconds>(now))};
+
+  auto shifted_date = date::year_month_day{date::floor<date::days>(now)} + calendar_shift_;
+  auto now_shifted = date::sys_days{shifted_date} + (now - date::floor<date::days>(now));
+  waybar_time shifted_wtime = {
+      locale_, date::make_zoned(time_zone, date::floor<std::chrono::seconds>(now_shifted))};
+
   std::string text = "";
   if (!is_timezone_fixed()) {
     // As date dep is not fully compatible, prefer fmt
@@ -109,18 +139,18 @@ auto waybar::modules::Clock::update() -> void {
 
   if (tooltipEnabled()) {
     if (config_["tooltip-format"].isString()) {
-      std::string calendar_lines = "";
-      std::string timezoned_time_lines = "";
+      std::string calendar_lines{""};
+      std::string timezoned_time_lines{""};
       if (is_calendar_in_tooltip_) {
-        calendar_lines = calendar_text(wtime);
+        calendar_lines = calendar_text(shifted_wtime);
       }
       if (is_timezoned_list_in_tooltip_) {
         timezoned_time_lines = timezones_text(&now);
       }
       auto tooltip_format = config_["tooltip-format"].asString();
-      text =
-          fmt::format(tooltip_format, wtime, fmt::arg(kCalendarPlaceholder.c_str(), calendar_lines),
-                      fmt::arg(KTimezonedTimeListPlaceholder.c_str(), timezoned_time_lines));
+      text = fmt::format(tooltip_format, shifted_wtime,
+                         fmt::arg(kCalendarPlaceholder.c_str(), calendar_lines),
+                         fmt::arg(KTimezonedTimeListPlaceholder.c_str(), timezoned_time_lines));
       label_.set_tooltip_markup(text);
     }
   }
@@ -136,20 +166,30 @@ bool waybar::modules::Clock::handleScroll(GdkEventScroll* e) {
   }
 
   auto dir = AModule::getScrollDir(e);
-  if (dir != SCROLL_DIR::UP && dir != SCROLL_DIR::DOWN) {
-    return true;
-  }
-  if (time_zones_.size() == 1) {
-    return true;
-  }
 
-  auto nr_zones = time_zones_.size();
-  if (dir == SCROLL_DIR::UP) {
-    size_t new_idx = current_time_zone_idx_ + 1;
-    current_time_zone_idx_ = new_idx == nr_zones ? 0 : new_idx;
+  // Shift calendar date
+  if (calendar_shift_init_.count() != 0) {
+    if (dir == SCROLL_DIR::UP)
+      calendar_shift_ += calendar_shift_init_;
+    else
+      calendar_shift_ -= calendar_shift_init_;
   } else {
-    current_time_zone_idx_ =
-        current_time_zone_idx_ == 0 ? nr_zones - 1 : current_time_zone_idx_ - 1;
+    // Change time zone
+    if (dir != SCROLL_DIR::UP && dir != SCROLL_DIR::DOWN) {
+      return true;
+    }
+    if (time_zones_.size() == 1) {
+      return true;
+    }
+
+    auto nr_zones = time_zones_.size();
+    if (dir == SCROLL_DIR::UP) {
+      size_t new_idx = current_time_zone_idx_ + 1;
+      current_time_zone_idx_ = new_idx == nr_zones ? 0 : new_idx;
+    } else {
+      current_time_zone_idx_ =
+          current_time_zone_idx_ == 0 ? nr_zones - 1 : current_time_zone_idx_ - 1;
+    }
   }
 
   update();
@@ -158,66 +198,72 @@ bool waybar::modules::Clock::handleScroll(GdkEventScroll* e) {
 
 auto waybar::modules::Clock::calendar_text(const waybar_time& wtime) -> std::string {
   const auto daypoint = date::floor<date::days>(wtime.ztime.get_local_time());
-  const auto ymd = date::year_month_day(daypoint);
-  if (cached_calendar_ymd_ == ymd) {
-    return cached_calendar_text_;
+  const auto ymd{date::year_month_day{daypoint}};
+
+  if (calendar_cached_ymd_ == ymd) {
+    return calendar_cached_text_;
   }
 
-  const date::year_month ym(ymd.year(), ymd.month());
-  const auto curr_day = ymd.day();
+  const auto curr_day{(calendar_shift_init_.count() != 0 && calendar_shift_.count() != 0)
+                          ? date::day{0}
+                          : ymd.day()};
+  const date::year_month ym{ymd.year(), ymd.month()};
+  const auto first_dow = first_day_of_week();
 
   std::stringstream os;
 
-  const auto first_dow = first_day_of_week();
-  int ws{0};  // weeks-pos: side(1 - left, 2 - right)
-  int wn{0};  // weeknumber
+  enum class WeeksSide {
+    LEFT,
+    RIGHT,
+    HIDDEN,
+  };
+  WeeksSide weeks_pos = WeeksSide::HIDDEN;
+
   if (config_["calendar-weeks-pos"].isString()) {
-    wn = (date::sys_days{date::year_month_day{ym / 1}} -
-          date::sys_days{date::year_month_day{ymd.year() / 1 / 1}})
-                 .count() /
-             7 +
-         1;
     if (config_["calendar-weeks-pos"].asString() == "left") {
-      ws = 1;
+      weeks_pos = WeeksSide::LEFT;
       // Add paddings before the header
-      os << std::string(4, ' ');
+      os << std::string(3 + fmt_weeks_left_pad_, ' ');
     } else if (config_["calendar-weeks-pos"].asString() == "right") {
-      ws = 2;
+      weeks_pos = WeeksSide::RIGHT;
     }
   }
 
   weekdays_header(first_dow, os);
-  /* Print weeknumber on the left for the first row*/
-  if (ws == 1) {
-    print_iso_weeknum(os, wn);
-    os << ' ';
-    ++wn;
-  }
-  // First week prefixed with spaces if needed.
-  auto wd = date::weekday(ym / 1);
+
+  // First week day prefixed with spaces if needed.
+  date::sys_days print_wd{ym / 1};
+  auto wd{date::weekday{print_wd}};
   auto empty_days = (wd - first_dow).count();
+
+  /* Print weeknumber on the left for the first row*/
+  if (weeks_pos == WeeksSide::LEFT) {
+    os << fmt::format(fmt_str_weeks_, print_wd) << ' ';
+  }
+
   if (empty_days > 0) {
     os << std::string(empty_days * 3 - 1, ' ');
   }
-  auto last_day = (ym / date::literals::last).day();
-  for (auto d = date::day(1); d <= last_day; ++d, ++wd) {
+
+  const auto last_day = (ym / date::literals::last).day();
+
+  for (auto d{date::day{1}}; d <= last_day; ++d, ++wd) {
     if (wd != first_dow) {
       os << ' ';
     } else if (unsigned(d) != 1) {
-      if (ws == 2) {
-        os << ' ';
-        print_iso_weeknum(os, wn);
-        ++wn;
+      if (weeks_pos == WeeksSide::RIGHT) {
+        os << ' ' << fmt::format(fmt_str_weeks_, print_wd);
       }
 
       os << '\n';
 
-      if (ws == 1) {
-        print_iso_weeknum(os, wn);
-        os << ' ';
-        ++wn;
+      print_wd = (ym / d);
+
+      if (weeks_pos == WeeksSide::LEFT) {
+        os << fmt::format(fmt_str_weeks_, print_wd) << ' ';
       }
     }
+
     if (d == curr_day) {
       if (config_["today-format"].isString()) {
         auto today_format = config_["today-format"].asString();
@@ -225,32 +271,34 @@ auto waybar::modules::Clock::calendar_text(const waybar_time& wtime) -> std::str
       } else {
         os << "<b><u>" << date::format("%e", d) << "</u></b>";
       }
-    } else if (config_["format-calendar"].isString()) {
-      os << fmt::format(config_["format-calendar"].asString(), date::format("%e", d));
-    } else
-      os << date::format("%e", d);
+    } else {
+      os << fmt::format(fmt_str_calendar_, date::format("%e", d));
+    }
     /*Print weeks on the right when the endings with spaces*/
-    if (ws == 2 && d == last_day) {
+    if (weeks_pos == WeeksSide::RIGHT && d == last_day) {
       empty_days = 6 - (wd.c_encoding() - first_dow.c_encoding());
-      if (empty_days > 0) {
-        os << std::string(empty_days * 3 + 1, ' ');
-        print_iso_weeknum(os, wn);
+      if (empty_days > 0 && empty_days < 7) {
+        os << std::string(empty_days * 3, ' ');
       }
+
+      os << ' ' << fmt::format(fmt_str_weeks_, print_wd);
     }
   }
 
   auto result = os.str();
-  cached_calendar_ymd_ = ymd;
-  cached_calendar_text_ = result;
+  calendar_cached_ymd_ = ymd;
+  calendar_cached_text_ = result;
   return result;
 }
 
-auto waybar::modules::Clock::weekdays_header(const date::weekday& first_dow, std::ostream& os)
+auto waybar::modules::Clock::weekdays_header(const date::weekday& first_week_day, std::ostream& os)
     -> void {
   std::stringstream res;
-  auto wd = first_dow;
+  auto wd = first_week_day;
   do {
-    if (wd != first_dow) res << ' ';
+    if (wd != first_week_day) {
+      res << ' ';
+    }
     Glib::ustring wd_ustring(date::format(locale_, "%a", wd));
     auto clen = ustring_clen(wd_ustring);
     auto wd_len = wd_ustring.length();
@@ -261,8 +309,8 @@ auto waybar::modules::Clock::weekdays_header(const date::weekday& first_dow, std
     }
     const std::string pad(2 - clen, ' ');
     res << pad << wd_ustring;
-  } while (++wd != first_dow);
-  res << "\n";
+  } while (++wd != first_week_day);
+  res << '\n';
 
   if (config_["format-calendar-weekdays"].isString()) {
     os << fmt::format(config_["format-calendar-weekdays"].asString(), res.str());
@@ -286,21 +334,11 @@ auto waybar::modules::Clock::timezones_text(std::chrono::system_clock::time_poin
       timezone = date::current_zone();
     }
     wtime = {locale_, date::make_zoned(timezone, date::floor<std::chrono::seconds>(*now))};
-    os << fmt::format(format_, wtime) << "\n";
+    os << fmt::format(format_, wtime) << '\n';
   }
   return os.str();
 }
 
-auto waybar::modules::Clock::print_iso_weeknum(std::ostream& os, int weeknum) -> void {
-  std::stringstream res;
-  res << std::setfill('0') << std::setw(2) << weeknum;
-
-  if (config_["format-calendar-weeks"].isString()) {
-    os << fmt::format(config_["format-calendar-weeks"].asString(), res.str());
-  } else
-    os << res.str();
-}
-
 #ifdef HAVE_LANGINFO_1STDAY
 template <auto fn>
 using deleter_from_fn = std::integral_constant<decltype(fn), fn>;
