@@ -1,16 +1,19 @@
-#include "modules/cpu.hpp"
-
+#include <spdlog/spdlog.h>
+// clang-format off
 #include <sys/types.h>
 #include <sys/sysctl.h>
-#include <spdlog/spdlog.h>
-#include <cstdlib>            // malloc
-#include <unistd.h>           // sysconf
-#include <cmath>              // NAN
+// clang-format on
+#include <unistd.h>  // sysconf
+
+#include <cmath>    // NAN
+#include <cstdlib>  // malloc
+
+#include "modules/cpu.hpp"
 
 #if defined(__NetBSD__) || defined(__OpenBSD__)
-#  include <sys/sched.h>
+#include <sys/sched.h>
 #else
-#  include <sys/resource.h>
+#include <sys/resource.h>
 #endif
 
 #if defined(__NetBSD__)
@@ -32,26 +35,26 @@ std::vector<std::tuple<size_t, size_t>> waybar::modules::Cpu::parseCpuinfo() {
   pcp_time_t *cp_time = static_cast<pcp_time_t *>(malloc(sz)), *pcp_time = cp_time;
 #if defined(__NetBSD__)
   int mib[] = {
-    CTL_KERN,
-    KERN_CP_TIME,
+      CTL_KERN,
+      KERN_CP_TIME,
   };
-  if (sysctl(mib, sizeof(mib)/sizeof(mib[0]), sum_cp_time, &sum_sz, NULL, 0)) {
+  if (sysctl(mib, sizeof(mib) / sizeof(mib[0]), sum_cp_time, &sum_sz, NULL, 0)) {
     throw std::runtime_error("sysctl kern.cp_time failed");
   }
   for (int state = 0; state < CPUSTATES; state++) {
     cp_time[state] = sum_cp_time[state];
   }
   pcp_time += CPUSTATES;
-  if (sysctl(mib, sizeof(mib)/sizeof(mib[0]), pcp_time, &sz, NULL, 0)) {
+  if (sysctl(mib, sizeof(mib) / sizeof(mib[0]), pcp_time, &sz, NULL, 0)) {
     throw std::runtime_error("sysctl kern.cp_time failed");
   }
 #elif defined(__OpenBSD__)
   {
     int mib[] = {
-      CTL_KERN,
-      KERN_CPTIME,
+        CTL_KERN,
+        KERN_CPTIME,
     };
-    if (sysctl(mib, sizeof(mib)/sizeof(mib[0]), sum_cp_time, &sum_sz, NULL, 0)) {
+    if (sysctl(mib, sizeof(mib) / sizeof(mib[0]), sum_cp_time, &sum_sz, NULL, 0)) {
       throw std::runtime_error("sysctl kern.cp_time failed");
     }
   }
@@ -62,14 +65,14 @@ std::vector<std::tuple<size_t, size_t>> waybar::modules::Cpu::parseCpuinfo() {
   sz /= ncpu + 1;
   {
     int mib[] = {
-      CTL_KERN,
-      KERN_CPTIME2,
-      0,
+        CTL_KERN,
+        KERN_CPTIME2,
+        0,
     };
     for (int cpu = 0; cpu < ncpu; cpu++) {
       mib[2] = cpu;
       pcp_time += CPUSTATES;
-      if (sysctl(mib, sizeof(mib)/sizeof(mib[0]), pcp_time, &sz, NULL, 0)) {
+      if (sysctl(mib, sizeof(mib) / sizeof(mib[0]), pcp_time, &sz, NULL, 0)) {
         throw std::runtime_error("sysctl kern.cp_time2 failed");
       }
     }
@@ -101,7 +104,8 @@ std::vector<std::tuple<size_t, size_t>> waybar::modules::Cpu::parseCpuinfo() {
 std::vector<float> waybar::modules::Cpu::parseCpuFrequencies() {
   static std::vector<float> frequencies;
   if (frequencies.empty()) {
-    spdlog::warn("cpu/bsd: parseCpuFrequencies is not implemented, expect garbage in {*_frequency}");
+    spdlog::warn(
+        "cpu/bsd: parseCpuFrequencies is not implemented, expect garbage in {*_frequency}");
     frequencies.push_back(NAN);
   }
   return frequencies;
