@@ -1,4 +1,5 @@
 #include "modules/simpleclock.hpp"
+
 #include <time.h>
 
 waybar::modules::Clock::Clock(const std::string& id, const Json::Value& config)
@@ -6,14 +7,15 @@ waybar::modules::Clock::Clock(const std::string& id, const Json::Value& config)
   thread_ = [this] {
     dp.emit();
     auto now = std::chrono::system_clock::now();
-    auto timeout = std::chrono::floor<std::chrono::seconds>(now + interval_);
-    auto diff = std::chrono::seconds(timeout.time_since_epoch().count() % interval_.count());
-    thread_.sleep_until(timeout - diff);
+    /* difference with projected wakeup time */
+    auto diff = now.time_since_epoch() % interval_;
+    /* sleep until the next projected time */
+    thread_.sleep_for(interval_ - diff);
   };
 }
 
 auto waybar::modules::Clock::update() -> void {
-  tzset(); // Update timezone information
+  tzset();  // Update timezone information
   auto now = std::chrono::system_clock::now();
   auto localtime = fmt::localtime(std::chrono::system_clock::to_time_t(now));
   auto text = fmt::format(format_, localtime);
