@@ -1,4 +1,5 @@
 #include "modules/sni/watcher.hpp"
+
 #include <spdlog/spdlog.h>
 
 using namespace waybar::modules::SNI;
@@ -29,8 +30,8 @@ Watcher::~Watcher() {
 
 void Watcher::busAcquired(const Glib::RefPtr<Gio::DBus::Connection>& conn, Glib::ustring name) {
   GError* error = nullptr;
-  g_dbus_interface_skeleton_export(
-      G_DBUS_INTERFACE_SKELETON(watcher_), conn->gobj(), "/StatusNotifierWatcher", &error);
+  g_dbus_interface_skeleton_export(G_DBUS_INTERFACE_SKELETON(watcher_), conn->gobj(),
+                                   "/StatusNotifierWatcher", &error);
   if (error != nullptr) {
     // Don't print an error when a watcher is already present
     if (error->code != 2) {
@@ -39,10 +40,10 @@ void Watcher::busAcquired(const Glib::RefPtr<Gio::DBus::Connection>& conn, Glib:
     g_error_free(error);
     return;
   }
-  g_signal_connect_swapped(
-      watcher_, "handle-register-item", G_CALLBACK(&Watcher::handleRegisterItem), this);
-  g_signal_connect_swapped(
-      watcher_, "handle-register-host", G_CALLBACK(&Watcher::handleRegisterHost), this);
+  g_signal_connect_swapped(watcher_, "handle-register-item",
+                           G_CALLBACK(&Watcher::handleRegisterItem), this);
+  g_signal_connect_swapped(watcher_, "handle-register-host",
+                           G_CALLBACK(&Watcher::handleRegisterHost), this);
 }
 
 gboolean Watcher::handleRegisterHost(Watcher* obj, GDBusMethodInvocation* invocation,
@@ -55,22 +56,16 @@ gboolean Watcher::handleRegisterHost(Watcher* obj, GDBusMethodInvocation* invoca
     object_path = service;
   }
   if (g_dbus_is_name(bus_name) == FALSE) {
-    g_dbus_method_invocation_return_error(invocation,
-                                          G_DBUS_ERROR,
-                                          G_DBUS_ERROR_INVALID_ARGS,
-                                          "D-Bus bus name '%s' is not valid",
-                                          bus_name);
+    g_dbus_method_invocation_return_error(invocation, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS,
+                                          "D-Bus bus name '%s' is not valid", bus_name);
     return TRUE;
   }
   auto watch = gfWatchFind(obj->hosts_, bus_name, object_path);
   if (watch != nullptr) {
     g_dbus_method_invocation_return_error(
-        invocation,
-        G_DBUS_ERROR,
-        G_DBUS_ERROR_INVALID_ARGS,
+        invocation, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS,
         "Status Notifier Host with bus name '%s' and object path '%s' is already registered",
-        bus_name,
-        object_path);
+        bus_name, object_path);
     return TRUE;
   }
   watch = gfWatchNew(GF_WATCH_TYPE_HOST, service, bus_name, object_path, obj);
@@ -93,18 +88,14 @@ gboolean Watcher::handleRegisterItem(Watcher* obj, GDBusMethodInvocation* invoca
     object_path = service;
   }
   if (g_dbus_is_name(bus_name) == FALSE) {
-    g_dbus_method_invocation_return_error(invocation,
-                                          G_DBUS_ERROR,
-                                          G_DBUS_ERROR_INVALID_ARGS,
-                                          "D-Bus bus name '%s' is not valid",
-                                          bus_name);
+    g_dbus_method_invocation_return_error(invocation, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS,
+                                          "D-Bus bus name '%s' is not valid", bus_name);
     return TRUE;
   }
   auto watch = gfWatchFind(obj->items_, bus_name, object_path);
   if (watch != nullptr) {
     g_warning("Status Notifier Item with bus name '%s' and object path '%s' is already registered",
-              bus_name,
-              object_path);
+              bus_name, object_path);
     sn_watcher_complete_register_item(obj->watcher_, invocation);
     return TRUE;
   }
@@ -152,13 +143,8 @@ Watcher::GfWatch* Watcher::gfWatchNew(GfWatchType type, const gchar* service, co
   watch->service = g_strdup(service);
   watch->bus_name = g_strdup(bus_name);
   watch->object_path = g_strdup(object_path);
-  watch->watch_id = g_bus_watch_name(G_BUS_TYPE_SESSION,
-                                     bus_name,
-                                     G_BUS_NAME_WATCHER_FLAGS_NONE,
-                                     nullptr,
-                                     &Watcher::nameVanished,
-                                     watch,
-                                     nullptr);
+  watch->watch_id = g_bus_watch_name(G_BUS_TYPE_SESSION, bus_name, G_BUS_NAME_WATCHER_FLAGS_NONE,
+                                     nullptr, &Watcher::nameVanished, watch, nullptr);
   return watch;
 }
 
@@ -183,12 +169,12 @@ void Watcher::updateRegisteredItems(SnWatcher* obj) {
   GVariantBuilder builder;
   g_variant_builder_init(&builder, G_VARIANT_TYPE("as"));
   for (GSList* l = items_; l != nullptr; l = g_slist_next(l)) {
-    auto   watch = static_cast<GfWatch*>(l->data);
+    auto watch = static_cast<GfWatch*>(l->data);
     gchar* item = g_strdup_printf("%s%s", watch->bus_name, watch->object_path);
     g_variant_builder_add(&builder, "s", item);
     g_free(item);
   }
-  GVariant*     variant = g_variant_builder_end(&builder);
+  GVariant* variant = g_variant_builder_end(&builder);
   const gchar** items = g_variant_get_strv(variant, nullptr);
   sn_watcher_set_registered_items(obj, items);
   g_variant_unref(variant);
