@@ -8,7 +8,7 @@
 
 namespace waybar::modules::sway {
 
-// Helper function to to assign a number to a workspace, just like sway. In fact
+// Helper function to assign a number to a workspace, just like sway. In fact
 // this is taken quite verbatim from `sway/ipc-json.c`.
 int Workspaces::convertWorkspaceNameToNum(std::string name) {
   if (isdigit(name[0])) {
@@ -130,6 +130,10 @@ void Workspaces::onCmd(const struct Ipc::ipc_response &res) {
         // In a first pass, the maximum "num" value is computed to enqueue
         // unnumbered workspaces behind numbered ones when computing the sort
         // attribute.
+        //
+        // Note: if the 'alphabetical_sort' option is true, the user is in
+        // agreement that the "workspace prev/next" commands may not follow
+        // the order displayed in Waybar.
         int max_num = -1;
         for (auto &workspace : workspaces_) {
           max_num = std::max(workspace["num"].asInt(), max_num);
@@ -143,16 +147,19 @@ void Workspaces::onCmd(const struct Ipc::ipc_response &res) {
           }
         }
         std::sort(workspaces_.begin(), workspaces_.end(),
-                  [](const Json::Value &lhs, const Json::Value &rhs) {
+                  [this](const Json::Value &lhs, const Json::Value &rhs) {
                     auto lname = lhs["name"].asString();
                     auto rname = rhs["name"].asString();
                     int l = lhs["sort"].asInt();
                     int r = rhs["sort"].asInt();
 
-                    if (l == r) {
+                    if (l == r || config_["alphabetical_sort"].asBool()) {
                       // In case both integers are the same, lexicographical
                       // sort. The code above already ensure that this will only
                       // happend in case of explicitly numbered workspaces.
+                      //
+                      // Additionally, if the config specifies to sort workspaces
+                      // alphabetically do this here.
                       return lname < rname;
                     }
 
