@@ -15,6 +15,7 @@
 #include <sstream>
 #include <utility>
 
+#include "gdkmm/general.h"
 #include "glibmm/error.h"
 #include "glibmm/fileutils.h"
 #include "glibmm/refptr.h"
@@ -173,18 +174,25 @@ bool Task::image_load_icon(Gtk::Image &image, const Glib::RefPtr<Gtk::IconTheme>
   }
 
   Glib::RefPtr<Gdk::Pixbuf> pixbuf;
+  auto scaled_icon_size = size * image.get_scale_factor();
 
   try {
-    pixbuf = icon_theme->load_icon(ret_icon_name, size, Gtk::ICON_LOOKUP_FORCE_SIZE);
+    pixbuf = icon_theme->load_icon(ret_icon_name, scaled_icon_size, Gtk::ICON_LOOKUP_FORCE_SIZE);
   } catch (...) {
     if (Glib::file_test(ret_icon_name, Glib::FILE_TEST_EXISTS))
-      pixbuf = load_icon_from_file(ret_icon_name, size);
+      pixbuf = load_icon_from_file(ret_icon_name, scaled_icon_size);
     else
       pixbuf = {};
   }
 
   if (pixbuf) {
-    image.set(pixbuf);
+    if (pixbuf->get_width() != scaled_icon_size) {
+      int width = scaled_icon_size * pixbuf->get_width() / pixbuf->get_height();
+      pixbuf = pixbuf->scale_simple(width, scaled_icon_size, Gdk::InterpType::INTERP_BILINEAR);
+    }
+    auto surface = Gdk::Cairo::create_surface_from_pixbuf(pixbuf, image.get_scale_factor(),
+                                                          image.get_window());
+    image.set(surface);
     return true;
   }
 
@@ -243,6 +251,9 @@ static const struct zwlr_foreign_toplevel_handle_v1_listener toplevel_handle_imp
     .parent = tl_handle_parent,
 };
 
+static const std::vector<Gtk::TargetEntry> target_entries = {
+    Gtk::TargetEntry("WAYBAR_TOPLEVEL", Gtk::TARGET_SAME_APP, 0)};
+
 Task::Task(const waybar::Bar &bar, const Json::Value &config, Taskbar *tbar,
            struct zwlr_foreign_toplevel_handle_v1 *tl_handle, struct wl_seat *seat)
     : bar_{bar},
@@ -301,9 +312,22 @@ Task::Task(const waybar::Bar &bar, const Json::Value &config, Taskbar *tbar,
   /* Handle click events if configured */
   if (config_["on-click"].isString() || config_["on-click-middle"].isString() ||
       config_["on-click-right"].isString()) {
-    button_.add_events(Gdk::BUTTON_PRESS_MASK);
-    button_.signal_button_press_event().connect(sigc::mem_fun(*this, &Task::handle_clicked), false);
   }
+
+  button_.add_events(Gdk::BUTTON_PRESS_MASK);
+  button_.signal_button_press_event().connect(sigc::mem_fun(*this, &Task::handle_clicked), false);
+  button_.signal_button_release_event().connect(sigc::mem_fun(*this, &Task::handle_button_release),
+                                                false);
+
+  button_.signal_motion_notify_event().connect(sigc::mem_fun(*this, &Task::handle_motion_notify),
+                                               false);
+
+  button_.drag_source_set(target_entries, Gdk::BUTTON1_MASK, Gdk::ACTION_MOVE);
+  button_.drag_dest_set(target_entries, Gtk::DEST_DEFAULT_ALL, Gdk::ACTION_MOVE);
+
+  button_.signal_drag_data_get().connect(sigc::mem_fun(*this, &Task::handle_drag_data_get), false);
+  button_.signal_drag_data_received().connect(
+      sigc::mem_fun(*this, &Task::handle_drag_data_received), false);
 }
 
 Task::~Task() {
@@ -487,6 +511,14 @@ void Task::handle_closed() {
 }
 
 bool Task::handle_clicked(GdkEventButton *bt) {
+  /* filter out additional events for double/triple clicks */
+  if (bt->type == GDK_BUTTON_PRESS) {
+    /* save where the button press ocurred in case it becomes a drag */
+    drag_start_button = bt->button;
+    drag_start_x = bt->x;
+    drag_start_y = bt->y;
+  }
+
   std::string action;
   if (config_["on-click"].isString() && bt->button == 1)
     action = config_["on-click"].asString();
@@ -520,6 +552,54 @@ bool Task::handle_clicked(GdkEventButton *bt) {
   return true;
 }
 
+bool Task::handle_button_release(GdkEventButton *bt) {
+  drag_start_button = -1;
+  return false;
+}
+
+bool Task::handle_motion_notify(GdkEventMotion *mn) {
+  if (drag_start_button == -1) return false;
+
+  if (button_.drag_check_threshold(drag_start_x, drag_start_y, mn->x, mn->y)) {
+    /* start drag in addition to other assigned action */
+    auto target_list = Gtk::TargetList::create(target_entries);
+    auto refptr = Glib::RefPtr<Gtk::TargetList>(target_list);
+    auto drag_context =
+        button_.drag_begin(refptr, Gdk::DragAction::ACTION_MOVE, drag_start_button, (GdkEvent *)mn);
+  }
+
+  return false;
+}
+
+void Task::handle_drag_data_get(const Glib::RefPtr<Gdk::DragContext> &context,
+                                Gtk::SelectionData &selection_data, guint info, guint time) {
+  spdlog::debug("drag_data_get");
+  void *button_addr = (void *)&this->button_;
+
+  selection_data.set("WAYBAR_TOPLEVEL", 32, (const guchar *)&button_addr, sizeof(gpointer));
+}
+
+void Task::handle_drag_data_received(const Glib::RefPtr<Gdk::DragContext> &context, int x, int y,
+                                     Gtk::SelectionData selection_data, guint info, guint time) {
+  spdlog::debug("drag_data_received");
+  gpointer handle = *(gpointer *)selection_data.get_data();
+  auto dragged_button = (Gtk::Button *)handle;
+
+  if (dragged_button == &this->button_) return;
+
+  auto parent_of_dragged = dragged_button->get_parent();
+  auto parent_of_dest = this->button_.get_parent();
+
+  if (parent_of_dragged != parent_of_dest) return;
+
+  auto box = (Gtk::Box *)parent_of_dragged;
+
+  auto position_prop = box->child_property_position(this->button_);
+  auto position = position_prop.get_value();
+
+  box->reorder_child(*dragged_button, position);
+}
+
 bool Task::operator==(const Task &o) const { return o.id_ == id_; }
 
 bool Task::operator!=(const Task &o) const { return o.id_ != id_; }
