@@ -6,8 +6,10 @@
 
 #include <algorithm>
 #include <iterator>
+#include <stdexcept>
 #include <vector>
 
+#include "client.hpp"
 #include "gtkmm/widget.h"
 #include "modules/wlr/workspace_manager_binding.hpp"
 
@@ -32,6 +34,11 @@ WorkspaceManager::WorkspaceManager(const std::string &id, const waybar::Bar &bar
     sort_by_coordinates_ = config_sort_by_coordinates.asBool();
   }
 
+  auto config_sort_by_number = config_["sort-by-number"];
+  if (config_sort_by_number.isBool()) {
+    sort_by_number_ = config_sort_by_number.asBool();
+  }
+
   auto config_all_outputs = config_["all-outputs"];
   if (config_all_outputs.isBool()) {
     all_outputs_ = config_all_outputs.asBool();
@@ -61,6 +68,15 @@ auto WorkspaceManager::workspace_comparator() const
     auto is_name_less = lhs->get_name() < rhs->get_name();
     auto is_name_eq = lhs->get_name() == rhs->get_name();
     auto is_coords_less = lhs->get_coords() < rhs->get_coords();
+
+    if (sort_by_number_) {
+      try {
+        auto is_number_less = std::stoi(lhs->get_name()) < std::stoi(rhs->get_name());
+        return is_number_less;
+      } catch (std::invalid_argument) {
+      }
+    }
+
     if (sort_by_name_) {
       if (sort_by_coordinates_) {
         return is_name_eq ? is_coords_less : is_name_less;
@@ -151,8 +167,20 @@ WorkspaceManager::~WorkspaceManager() {
     return;
   }
 
-  zext_workspace_manager_v1_destroy(workspace_manager_);
-  workspace_manager_ = nullptr;
+  wl_display *display = Client::inst()->wl_display;
+
+  // Send `stop` request and wait for one roundtrip. This is not quite correct as
+  // the protocol encourages us to wait for the .finished event, but it should work
+  // with wlroots workspace manager implementation.
+  zext_workspace_manager_v1_stop(workspace_manager_);
+  wl_display_roundtrip(display);
+
+  // If the .finished handler is still not executed, destroy the workspace manager here.
+  if (workspace_manager_) {
+    spdlog::warn("Foreign toplevel manager destroyed before .finished event");
+    zext_workspace_manager_v1_destroy(workspace_manager_);
+    workspace_manager_ = nullptr;
+  }
 }
 
 auto WorkspaceManager::remove_workspace_group(uint32_t id) -> void {
