@@ -39,8 +39,8 @@ waybar::util::Rfkill::Rfkill(const enum rfkill_type rfkill_type) : rfkill_type_(
     fd_ = -1;
     return;
   }
-  Glib::signal_io().connect(
-      sigc::mem_fun(*this, &Rfkill::on_event), fd_, Glib::IO_IN | Glib::IO_ERR | Glib::IO_HUP);
+  Glib::signal_io().connect(sigc::mem_fun(*this, &Rfkill::on_event), fd_,
+                            Glib::IO_IN | Glib::IO_ERR | Glib::IO_HUP);
 }
 
 waybar::util::Rfkill::~Rfkill() {
@@ -52,7 +52,7 @@ waybar::util::Rfkill::~Rfkill() {
 bool waybar::util::Rfkill::on_event(Glib::IOCondition cond) {
   if (cond & Glib::IO_IN) {
     struct rfkill_event event;
-    ssize_t             len;
+    ssize_t len;
 
     len = read(fd_, &event, sizeof(event));
     if (len < 0) {
